@@ -115,7 +115,11 @@ mod imp {
                     #[weak(rename_to = obj)]
                     self.obj(),
                     move |_camera, data| {
-                        let Ok(uri) = data.parse::<WormholeTransferURI>() else {
+                        let Ok(utf8) = std::str::from_utf8(&data) else {
+                            return;
+                        };
+
+                        let Ok(uri) = utf8.parse::<WormholeTransferURI>() else {
                             return;
                         };
 
@@ -303,6 +307,13 @@ impl WarpApplicationWindow {
         dialog.set_developers(&[&gettext("Fina Wilke")]);
         dialog.set_artists(&[&gettext("Tobias Bernard"), &gettext("Sophie Herold")]);
         dialog.set_translator_credits(&gettext("translator-credits"));
+        dialog.add_other_app(
+            "org.gnome.World.PikaBackup",
+            // Translators: This is a promotion and should match the app name as seen at https://apps.gnome.org/PikaBackup/
+            &gettext("Pika Backup"),
+            // Translators: This is a promotion and should match the short app summary as seen at https://apps.gnome.org/PikaBackup/
+            &gettext("Keep your data safe"),
+        );
         glib::spawn_future_local(glib::clone!(
             #[weak]
             dialog,
@@ -384,17 +395,21 @@ impl WarpApplicationWindow {
         );
     }
 
+    pub fn send_file(&self, file: &gio::File) {
+        if let Some(path) = file.path() {
+            log::debug!("Selected file: {}", path.display());
+            self.imp()
+                .action_view
+                .send_file(path, self.config().app_cfg());
+        } else {
+            log::error!("Can't send file: path is None");
+        }
+    }
+
     fn select_file_result(&self, result: Result<gio::File, glib::Error>) {
         match result {
             Ok(file) => {
-                if let Some(path) = file.path() {
-                    log::debug!("Picked file: {}", path.display());
-                    self.imp()
-                        .action_view
-                        .send_file(path, self.config().app_cfg());
-                } else {
-                    log::error!("File chooser has file but path is None");
-                }
+                self.send_file(&file);
             }
             Err(err) => {
                 log::debug!("File chooser error: {:?}", err);
